# Django Partitial Ajax

[![CircleCI](https://circleci.com/gh/eieste/django-partitialajax/tree/development.svg?style=svg)](https://circleci.com/gh/eieste/django-partitialajax/tree/development)
[![Coverage Status](https://coveralls.io/repos/github/eieste/django-partitialajax/badge.svg?branch=development)](https://coveralls.io/github/eieste/django-partitialajax?branch=development)
![PyPI - License](https://img.shields.io/pypi/l/django-partitialajax)
![NPM](https://img.shields.io/npm/l/django-partitialajax)
![Read the Docs](https://img.shields.io/readthedocs/django-partitialajax)
![npm](https://img.shields.io/npm/v/django-partitialajax)
![PyPI](https://img.shields.io/pypi/v/django-partitialajax)


This libary can you help to load Django-Rendered Partitials and embedd this into your page.

This libary consists of two parts: python/django and js lib;
you can install it via
```bash
pip3 install django-partitialajax
npm install django-partitialajax

```

For more Information read the docs